#!/bin/sh
check=no
expensive=no
logging=no
druplig=no
debug=no
vector=no
usage () {
cat 1>&2 <<EOF
usage: configure.sh [ <option> ... ]
where <option> is one of the following:
-h|--help      print this option summary

-g|--debug     switch on debugging (include symbols, check assertions)
-c|--check     enable assertion checking even in non-debugging mode
-e|--expensive enable expensive assertion checking
-l|--logging   enable detailed logging

--druplig      connect to DRUPLIG library code for online proof checking
               (requires http://fmv.jku.at/druplig)

-a|--all       enable all above options (for maximum debugging)

-v|--vector    use 'std::vector' instead of our own template
               this gives incorrect memory usage results
	       is in general slower but sometimes faster
EOF
exit 1
}
die () {
  echo "*** configure.sh: $*" 1>&2
  exit 1
}
while [ $# -gt 0 ]
do
  case $1 in
    -h|--help) usage;;
    -g|--debug) debug=yes;;
    -c|--check) check=yes;;
    -e|--expensive) check=yes;expensive=yes;;
    -l|--logging) logging=yes;;
    --druplig) druplig=yes;;
    -a|--all) debug=yes;check=yes;expensive=yes;logging=yes;druplig=yes;;
    -v|--vector) vector=yes;;
    *) die "invalid option '$1' (try '-h')";;
  esac
  shift
done
COMPILE="g++ -Wall"
if [ $debug = yes ]
then
  COMPILE="$COMPILE -g3"
else
  COMPILE="$COMPILE -O3"
  [ $check = no ] && COMPILE="$COMPILE -DNDEBUG"
fi
if [ $druplig = yes ]
then
  [ -d ../druplig ] || \
    die "no directory '../druplig'"
  [ -f ../druplig/druplig.h ] || \
    die "no header file '../druplig/druplig.h'"
  [ -f ../druplig/libdruplig.a ] || \
    die "no library '../druplig/libdruplig.a'"
  COMPILE="$COMPILE -DDRUPLIG -L../druplig"
  LIBS="-ldruplig"
else
  LIBS=""
fi
[ $expensive = yes ] && COMPILE="$COMPILE -DEXPENSIVECHECKS"
[ $logging = yes ] && COMPILE="$COMPILE -DLOGGING"
[ $vector = yes ] && COMPILE="$COMPILE -DVECTOR"
echo "$COMPILE"
rm -f makefile
sed \
-e "s,@COMPILE@,$COMPILE," \
-e "s,@LIBS@,$LIBS," \
makefile.in > makefile
